# distributo

**distributo** is a Python package for representing and manipulating probabilistic distributions, such as the Gaussian and the Binomial distributions.

## Files

The package is made up by the following files:

* `Generaldistribution.py`, which contains the `Distribution` superclass, a generic distribution class for calculating and visualizing a probability distribution;

* `Gaussiandistribution.py`, which contains the `Gaussian` class, a Distribution subclass for calculating and visualizing a Gaussian distribution;

* `Binomialdistribution.py`, which contains the `Binomial` class, a Distribution subclass for calculating and visualizing a Binomial distribution.

## Installation

Run the following command in the terminal to install the package:

```java
pip install distributo
```

## License

See the `license.txt` file or follow the link at [MIT License](https://mit-license.org/) for more information.
